@@ -3,7 +3,7 @@ from azure.storage.blob import BlockBlobService, ContentSettings
 from foqus.configuration import *
 from foqus.database import logger
 
-from io import IOBase
+from io import BytesIO
 
 import json
 import pickle
@@ -76,7 +76,7 @@ def load_parquet_from_azure(parquet_file):
     :param parquet_file: path of parquet file to load from MS azure blob
     :return: the vector data if exist else None
     '''
-    byte_stream = IOBase()
+    byte_stream = BytesIO()
     block_blob_service = BlockBlobService(account_name=AZURE_ACCOUNT_NAME,
                                           account_key=AZURE_ACCOUNT_KEY)
     try:
@@ -156,3 +156,49 @@ def load_vectors_from_azure(vectors):
     logger.info("Vectors keys : %s" % vectors.keys())
     return vectors
 
+
+def list_repository_files(prefix):
+    '''
+    :return: list of parquets file
+    '''
+    block_blob_service = BlockBlobService(account_name=AZURE_ACCOUNT_NAME,
+                                          account_key=AZURE_ACCOUNT_KEY)
+    generator = block_blob_service.list_blobs(AZURE_CONTAINER_NAME)
+    files = []
+    try:
+        for blob in generator:
+            if prefix in blob.name:
+                files.append(blob.name)
+    except Exception as e:
+        logger.error("Exception in listing parquet files ..." + str(e))
+    return files
+
+
+def create_delete_container_azure(container_name):
+    # container_name = "deleted-" + AZURE_CONTAINER_NAME
+    from azure.storage.blob import BlockBlobService, PublicAccess
+    blob_service = BlockBlobService(account_name=AZURE_ACCOUNT_NAME,
+                                    account_key=AZURE_ACCOUNT_KEY)
+    # container_name = "deleted-" + AZURE_CONTAINER_NAME
+    result = blob_service.create_container(container_name)
+    blob_service.set_container_acl(container_name, public_access=PublicAccess.Container)
+    if not result:
+        logger.info("Container already created")
+    return result
+
+
+def copy_azure_file(blob_name, copy_from_container, copy_to_container):
+    create_delete_container_azure(copy_to_container)
+    from azure.storage.blob import BlockBlobService
+    blob_service = BlockBlobService(account_name=AZURE_ACCOUNT_NAME,
+                                    account_key=AZURE_ACCOUNT_KEY)
+    try:
+        # except Exception as e:
+        blob_url = blob_service.make_blob_url(copy_from_container, blob_name)
+        # blob_url:https://demostorage.blob.core.windows.net/image-container/pretty.jpg
+
+        blob_service.copy_blob(copy_to_container, blob_name, blob_url)
+        #for move the file use this line
+        blob_service.delete_blob(copy_from_container, blob_name)
+    except Exception as e:
+        logger.info('blob_name  %s not found error is %s' % (blob_name, e))
\ No newline at end of file
