@@ -246,119 +246,193 @@ def image_extension(image_url):
         return image_url.split('.')[-1]
 
 
-def download_or_remove(urls, each_url_product, download_operation=1, customer_name=None, customer_type=None,
-                       db=None, path_out=None, project_name=None):
+def resize_and_retrieve(url, filename):
+    try:
+        response = requests.get(url)
+        img = Image.open(BytesIO(response.content))
+        img = img.resize((TARGET_RESOLUTION, TARGET_RESOLUTION))
+        img.save(filename)
+    except Exception as e:
+        logger.error("Error when resizing and downloading file %s error %s ..."
+                     % (url, e))
+
+
+def download_resized_image(url, filename):
+    '''
+    :param url: url of the file to download
+    :param filename: the file name to download to
+    :return:
+    '''
+    # As long as the file is opened in binary mode, both Python 2 and Python 3
+    # can write response body to it without decoding.
+    logger.info("******** Downloading image..")
+    start = time.process_time()
+    try:
+        res = all(ord(c) < 128 for c in url)
+        if res:
+            resize_and_retrieve(url.replace(' ', '+'), filename)
+        else:
+            url = urllib.parse.urlparse(url)
+            url = url.scheme + "://" + url.netloc + urllib.parse.quote(url.path)
+            resize_and_retrieve(url.replace(' ', '+'), filename)
+        logger.info("*** download time taken" + str(time.process_time() - start))
+        return filename
+    except Exception as e:
+        logger.error("Error when downloading/writing file %s error %s ..." % (filename, e))
+    url_extension = image_extension(url)
+    real_extension = imghdr.what(filename)
+    if real_extension != url_extension:
+        file_hash = filename.split('.')[0]
+        try:
+            res = all(ord(c) < 128 for c in url)
+            if res:
+                urllib.request.urlretrieve(url.replace(' ', '+'), file_hash + '.' + real_extension)
+            else:
+                url = urllib.parse.urlparse(url)
+                url = url.scheme + "://" + url.netloc + urllib.parse.quote(url.path)
+                resize_and_retrieve(url.replace(' ', '+'), file_hash + '.' + real_extension)
+            logger.info("*** download time taken" + str(time.process_time() - start))
+            return file_hash + '.' + real_extension
+        except Exception as e:
+            logger.error("Error when downloading/writing file %s error %s ..."
+                         % (file_hash + '.' + real_extension, e))
+            return None
+
+
+def products_related_data(url_images, url_produits, each_picture, each_url_product, path, customer_name,
+                          customer_type, project_name):
+    if each_url_product != '' and each_url_product in url_produits.keys():
+        reference = url_produits[each_url_product]['images']
+        new_reference = reference + " " + each_picture
+        url_produits[each_url_product] = {"images": new_reference,
+                                          "path": path,
+                                          "customer_name": customer_name,
+                                          "customer_type": customer_type,
+                                          "project_name": project_name}
+    elif each_url_product != '':
+        url_produits[each_url_product] = {"images": each_picture,
+                                          "path": path,
+                                          "customer_name": customer_name,
+                                          "customer_type": customer_type,
+                                          "project_name": project_name}
+    else:
+        url_images.append({"images": each_picture,
+                           "path": path,
+                           "customer_name": customer_name,
+                           "customer_type": customer_type,
+                           "project_name": project_name})
+
+
+def download_commit_db_images(url_images, url_produits):
+    if url_images:
+        for image in url_images:
+            try:
+                download_or_remove(image.get('images', ''), "", image.get("customer_name"),
+                                   image.get('customer_type'), db, image.get('path'), image.get('project_name'))
+            except Exception as e:
+                logger.error(
+                    'Error_url_images_download_commit_db_images_count %s downloading image %s continue' % (e, image))
+    else:
+        for product in url_produits.keys():
+            try:
+                download_or_remove(url_produits.get(product, {}).get('images', ''), product,
+                                   url_produits.get(product, {}).get("customer_name"),
+                                   url_produits.get(product, {}).get('customer_type'), db,
+                                   url_produits.get(product, {}).get('path'),
+                                   url_produits.get(product, {}).get('project_name'))
+            except Exception as e:
+                logger.error('Error_url_produits_download_commit_db_images_cont %s downloading image %s continue' %
+                             (e, url_produits[product]['images']))
+
+    db.commit_db_changes()
+
+
+def download_or_remove(urls, each_url_product, customer_name=None, customer_type=None, db=None, path_out=None,
+                       project_name=None):
+
     if customer_name is None or customer_type is None or db is None:
         logger.error("Cannot download image: missing parameters")
         return
-
     if path_out is None:
-        path_out = INPUT_PATH + customer_type + '/' + customer_name + '/images/' + project_name
-    input_s3 = INPUT_S3 + customer_type + '/' + customer_name + '/images/' + project_name + '/'
-    input_azure = AZURE_INPUT_PATH + customer_type + "/" + customer_name + "/images/" + project_name + '/'
-    resized_path = OUTPUT_PATH + customer_type + '/' + customer_name + '/images' + project_name + '/'
-    output_3 = OUTPUT_S3 + customer_type + '/' + customer_name + '/images/' + project_name + '/'
+        path_out = OUTPUT_PATH + customer_type + '/' + customer_name + '/images/' + project_name
+    input_s3 = OUTPUT_S3 + customer_type + '/' + customer_name + '/images/' + project_name + '/'
+    input_azure = AZURE_OUTPUT_PATH + customer_type + "/" + customer_name + "/images/" + project_name + '/'
     hash_files = ""
     for url in urls.split(' '):
         hash_file = get_remote_file_hash(url)
         extention = image_extension(url)
         filename = hash_file + '.' + extention
         fichier = path_out + '/' + filename
-        resized_fichier = resized_path + '/' + filename
 
         logger.info("Retrieving image from URL...")
 
-        logger.info("Image URL: " + url)
-        if download_operation == 1:
-            db.create_client_products_table(replace_special_caractere(customer_name).replace(' ', '_'))
+        db.create_client_products_table(replace_special_caractere(customer_name).replace(' ', '_'))
 
-            if os.path.exists(fichier) and os.stat(fichier).st_size == 0:
-                logger.info("File exists but size is 0... Download again!")
-                download(url, fichier)
-            elif not os.path.exists(fichier):
-                logger.info("File doesn't exist... Downloading...")
-                download(url, fichier)
-            else:
-                logger.info("File exists and not empty... Ignoring download.")
-
-            if os.path.exists(fichier) and os.stat(fichier).st_size == 0:
-                logger.info("File exists but size is 0... Download again!")
-                download(url, fichier)
-            elif not os.path.exists(fichier):
-                logger.info("File doesn't exist... Downloading...")
-                download(url, fichier)
-            else:
-                logger.info("File downloaded successfully.")
-
-            if USE_AWS:
-                upload_file_into_s3(fichier, input_s3 + fichier.split('/')[-2] + '/')
-            else:
-                if fichier.split('/')[-2] == project_name:
-                    file_azure = input_azure + fichier.split('/')[-1]
-                else:
-                    file_azure = input_azure + fichier.split('/')[-2] + '/' + fichier.split('/')[-1]
-                upload_file_into_azure(file_azure, fichier)
-            retries = 0
-            while get_file_hash(fichier) != hash_file and retries < MAX_DOWNLOAD_FILE_RETRIES:
-                logger.warning("File exists but hash is incorrect... Download again!")
-                hash_file = get_remote_file_hash(url)
-                download(url, fichier)
-                if USE_AWS:
-                    upload_file_into_s3(fichier, input_s3 + fichier.split('/')[-2] + '/')
-                else:
-                    if fichier.split('/')[-2] == project_name:
-                        file_azure = input_azure + fichier.split('/')[-1]
-                    else:
-                        file_azure = input_azure + fichier.split('/')[-2] + '/' + fichier.split('/')[-1]
-                    upload_file_into_azure(file_azure, fichier)
-                retries += 1
-
-            if get_file_hash(fichier) != hash_file:
-                logger.error("File wasn't downloaded correctly! " + fichier)
-            else:
-                logger.info("File was successfully downloaded (hash OK) >>> File path: " + fichier)
-
-            hash_files = hash_files + filename + " "
+        if os.path.exists(fichier) and os.stat(fichier).st_size != 0:
+            logger.info("File exists and not empty... Ignoring download.")
+        elif os.path.exists(fichier) and os.stat(fichier).st_size == 0:
+            logger.info("File exists but size is 0... Download again!")
+            start = time.process_time()
+            download_resized_image(url, fichier)
+            print("*** download time taken" + str(time.process_time() - start))
+        else:
+            logger.info("File doesn't exist... Downloading...")
+            download_resized_image(url, fichier)
+        if USE_AWS:
+            upload_file_into_s3(fichier, input_s3 + fichier.split('/')[-2] + '/')
         else:
-            if remove(db, resized_fichier) == 0 and delete_from_s3(
-                                            output_3 + fichier.split('/')[-2] + '/' + filename) == 0:
-                logger.info("Obsolete ad... Removing file from Output local and S3")
-            if remove(db, fichier) == 0 and delete_from_s3(input_s3 + fichier.split('/')[-2] + '/' + filename) == 0:
-                logger.info("Obsolete ad... Removing file from Input local and S3")
 
-    data_product = db.get_product_details(replace_special_caractere(customer_name).replace(' ', '_'), each_url_product,
-                                          project_name)
-    if data_product:
-        urls_base = data_product[1]
-        hash_base = data_product[3]
-        urls_references_base = data_product[1].split(' ')
-        hash_references_base = data_product[3].split(' ')
-        urls_references = urls.split(' ')
-        hash_references = hash_files.split(' ')
-        # hash_references = list(dict.fromkeys(hash_references))
-        for i in range(0, len(urls_references)-1):
-            for j in range(0, len(urls_references_base)-1):
-                if urls_references[i] == urls_references_base[j]:
-                    if hash_references[i] != hash_references_base[j]:
-                        # urls_base.replace(urls_references_base[j], urls_references[i])
-                        hash_base.replace(hash_references_base[j], hash_references[j])
-        # Url image has been changed
-        for i in range(0, len(hash_references) - 1):
-            for j in range(0, len(hash_references_base) - 1):
-                if hash_references[i] not in hash_references_base:
-                    hash_references_base.append(hash_references[i])
-                    urls_base = urls + urls_references_base[j] + " "
-                if hash_references[i] == hash_references_base[j]:
-                    if urls_references[i] != urls_references_base[j]:
-                        urls.replace(urls_references_base[j], urls_references[i])
+            if fichier.split('/')[-2] == project_name:
+                file_azure = input_azure + fichier.split('/')[-1]
+            else:
+                file_azure = input_azure + fichier.split('/')[-2] + '/' + fichier.split('/')[-1]
+            upload_file_into_azure(file_azure, fichier)
 
-    if each_url_product == '':
-        db.add_or_update_images(table_name=replace_special_caractere(customer_name).replace(' ', '_'),
-                                reference=urls, urlProduit="", hash_code=hash_files, project_name=project_name)
-    else:
-        db.add_or_update_products(table_name=replace_special_caractere(customer_name).replace(' ', '_'),
-                                  reference=urls, urlProduit=each_url_product, hash_code=hash_files,
-                                  project_name=project_name, update=data_product)
+        # while get_file_hash(fichier) != hash_file:
+        #     logger.warning("File exists but hash is incorrect... Download again!")
+        #     hash_file = get_remote_file_hash(url)
+        #     download_resized_image(url, fichier)
+        #     if USE_AWS:
+        #         upload_file_into_s3(fichier, input_s3 + fichier.split('/')[-2] + '/')
+
+        if get_file_hash(fichier) != hash_file:
+            logger.error("File wasn't downloaded correctly! " + fichier)
+        else:
+            logger.info("File was successfully downloaded (hash OK) >>> File path: " + fichier)
+        hash_files = hash_files + filename + " "
+        data_product = db.get_product_details(replace_special_caractere(customer_name).replace(' ', '_'),
+                                              each_url_product,
+                                              project_name)
+        if data_product:
+            hash_base = data_product[3]
+            urls_references_base = data_product[1].split(' ')
+            hash_references_base = data_product[3].split(' ')
+            urls_references = urls.split(' ')
+            hash_references = hash_files.split(' ')
+            # hash_references = list(dict.fromkeys(hash_references))
+            for i in range(0, len(urls_references) - 1):
+                for j in range(0, len(urls_references_base) - 1):
+                    if urls_references[i] == urls_references_base[j]:
+                        if hash_references[i] != hash_references_base[j]:
+                            # urls_base.replace(urls_references_base[j], urls_references[i])
+                            hash_base.replace(hash_references_base[j], hash_references[j])
+            # Url image has been changed
+            for i in range(0, len(hash_references) - 1):
+                for j in range(0, len(hash_references_base) - 1):
+                    if hash_references[i] not in hash_references_base:
+                        hash_references_base.append(hash_references[i])
+                        urls_base = urls + urls_references_base[j] + " "
+                    if hash_references[i] == hash_references_base[j]:
+                        if urls_references[i] != urls_references_base[j]:
+                            urls.replace(urls_references_base[j], urls_references[i])
+
+        if each_url_product == '':
+            db.add_or_update_images(table_name=replace_special_caractere(customer_name).replace(' ', '_'),
+                                    reference=urls, urlProduit="", hash_code=hash_files, project_name=project_name)
+        else:
+            db.add_or_update_products(table_name=replace_special_caractere(customer_name).replace(' ', '_'),
+                                      reference=urls, urlProduit=each_url_product, hash_code=hash_files,
+                                      project_name=project_name, update=data_product)
 
 
 def safe_download(url, file_path):
@@ -680,55 +754,6 @@ def add_max_post():
             db.update_max_number_post(10000, plan[3])
 
 
-def products_related_data(url_images, url_produits, each_picture, each_url_product, path, status,
-                          customer_name, customer_type, project_name):
-    if each_url_product != '' and each_url_product in url_produits.keys():
-        reference = url_produits[each_url_product]['images']
-        new_reference = reference + " " + each_picture
-        url_produits[each_url_product] = {"images": new_reference,
-                                          "path": path, "status": status,
-                                          "customer_name": customer_name,
-                                          "customer_type": customer_type,
-                                          "project_name": project_name}
-    elif each_url_product != '':
-        url_produits[each_url_product] = {"images": each_picture,
-                                          "path": path, "status": status,
-                                          "customer_name": customer_name,
-                                          "customer_type": customer_type,
-                                          "project_name": project_name}
-    else:
-        url_images.append({"images": each_picture,
-                           "path": path, "status": status,
-                           "customer_name": customer_name,
-                           "customer_type": customer_type,
-                           "project_name": project_name})
-
-
-def download_commit_db_images(url_images, url_produits):
-    if url_images:
-        for image in url_images:
-            try:
-                download_or_remove(image.get('images', ''), "", image.get('status'), image.get("customer_name"),
-                                   image.get('customer_type'), db, image.get('path'), image.get('project_name'))
-            except Exception as e:
-                logger.error(
-                    'Error_url_images_download_commit_db_images_count %s downloading image %s continue' % (e, image))
-    else:
-        for product in url_produits.keys():
-            try:
-                download_or_remove(url_produits.get(product, {}).get('images', ''), product,
-                                   url_produits.get(product, {}).get('status'),
-                                   url_produits.get(product, {}).get("customer_name"),
-                                   url_produits.get(product, {}).get('customer_type'), db,
-                                   url_produits.get(product, {}).get('path'),
-                                   url_produits.get(product, {}).get('project_name'))
-            except Exception as e:
-                logger.error('Error_url_produits_download_commit_db_images_cont %s downloading image %s continue' %
-                             (e, url_produits[product]['images']))
-
-    db.commit_db_changes()
-
-
 def get_count_product_validation(token, url_shop, plan):
     api_version = get_api_version_shopify()
     headers = {
