@@ -122,89 +122,6 @@ def create_project(customer_name, customer_type, api_project, project_name, proj
             return 0
 
 
-def delete_project(customer, customer_type, api_project, project_name, project_id):
-    name = project_name + "_deleted" + datetime.date.today().strftime("%Y-%m-%d")
-    db.update_status_name_deleted_project(name, 0, customer, customer_type, project_name, api_project)
-
-    if project_name != "" and api_project == "similars":
-        input_path_project_to_delete = INPUT_PATH + customer_type + '/' + customer + '/images/' + project_name
-        input_path_s3 = INPUT_S3 + customer_type + '/' + customer + '/images/' + project_name
-        output_path_project_to_delete = OUTPUT_PATH + customer_type + '/' + customer + '/images/' + project_name
-        output_path_s3 = OUTPUT_S3 + customer_type + '/' + customer + '/images/' + project_name
-        vectors_path_project_to_delete = VECTORS_PATH + customer_type + '/' + customer + '/' + project_name
-        vectors_path_s3 = VECTORS_S3 + customer_type + '/' + customer + '/' + project_name
-        streams_path_project_similars_to_delete = STREAMS_PATH + customer_type + '/' + customer + '/similars/' + \
-                                                  project_name
-        streams_path_3 = STREAMS_S3 + customer_type + '/' + customer + '/similars/' + \
-                                                  project_name
-        training_path_project_to_delete = TRAININGS_PATH + customer_type + '/' + customer + '/classification/' + \
-                                          project_name
-        training_path_s3_to_delete = TRAININGS_PATH + customer_type + '/' + customer + '/classification/' + \
-                                     project_name
-        try:
-            if os.path.isdir(input_path_project_to_delete):
-                move_directory(input_path_s3, 'deleted_project')
-                shutil.rmtree(input_path_project_to_delete)
-                logger.info("input path -------- DELETED")
-            if os.path.isdir(output_path_project_to_delete):
-                move_directory(output_path_s3, 'deleted_project')
-                shutil.rmtree(output_path_project_to_delete)
-                logger.info("output path -------- DELETED")
-            if os.path.isdir(vectors_path_project_to_delete):
-                move_directory(vectors_path_s3, 'deleted_project')
-                shutil.rmtree(vectors_path_project_to_delete)
-                logger.info("vectors path -------- DELETED")
-            if os.path.isdir(streams_path_project_similars_to_delete):
-                move_directory(streams_path_3, 'deleted_project')
-                shutil.rmtree(streams_path_project_similars_to_delete)
-                logger.info("streams path similars -------- DELETED")
-            if os.path.isdir(training_path_project_to_delete):
-                move_directory(training_path_s3_to_delete, 'deleted_project')
-                shutil.rmtree(training_path_project_to_delete)
-                logger.info("training classification path similars -------- DELETED")
-            return 1
-        except Exception as e:
-            logger.info("Error deleting similars project %s %s " % (project_name, e))
-            return 0
-    elif project_name != "" and api_project == "classification":
-        streams_path_project_classification_to_delete = STREAMS_PATH + customer_type + '/' + customer + \
-                                                        '/classification/' + project_name
-        streams_path_s3_classification_to_delete = STREAMS_S3 + customer_type + '/' + customer + \
-                                                   '/classification/' + project_name
-        training_path_project_to_delete = TRAININGS_PATH + customer_type + '/' + customer + '/classification/' + \
-                                          project_name
-        training_path_s3_to_delete = TRAININGS_PATH + customer_type + '/' + customer + '/classification/' + \
-                                          project_name
-        try:
-            if os.path.isdir(training_path_project_to_delete):
-                move_directory(training_path_s3_to_delete, 'deleted_project')
-                shutil.rmtree(training_path_project_to_delete)
-                logger.info("training path -------- DELETED")
-            if os.path.isdir(streams_path_project_classification_to_delete):
-                move_directory(streams_path_s3_classification_to_delete, 'deleted_project')
-                shutil.rmtree(streams_path_project_classification_to_delete)
-                logger.info("streams path classification -------- DELETED")
-            return 1
-        except Exception as e:
-            logger.info("Error deleting similars project %s %s " % (project_name, e))
-            return 0
-    elif project_name != "" and project_id and api_project == "detection_error":
-        list_directories = ['labels', 'images', 'bottlenecks', 'model', 'model_text', 'output', 'predictCustomerPATH',
-                            'tmp']
-        date_supp = strftime("%d-%m-%Y", gmtime())
-        for directory in list_directories:
-            directory_to_rename = TRAININGS_PATH + str(customer_type) + '/' + str(customer) + '/detection_erreur/' + \
-                                  directory + "/" + project_id
-            directory_s3_rename = TRAININGS_S3 + str(customer_type) + '/' + str(customer) + '/detection_erreur/' + \
-                                  directory + "/" + project_id
-
-            if os.path.isdir(directory_to_rename):
-                os.rename(directory_to_rename, directory_to_rename + '_deleted_' + str(date_supp))
-                logger.info("directory %s -------- RENAMED" % directory)
-                move_directory(directory_s3_rename, 'deleted_project')
-        return 1
-
-
 def get_all_plans_payement(customer_email, type_user_admin):
     type_user_sender = db.verif_permission(customerEmail=customer_email, type_user=type_user_admin)
     msg = "You are not allowed to get_all_plans_payement."
@@ -1429,12 +1346,20 @@ def delete_user_data(customer_name, customer_type):
             logger.info('Deleting_detection_error_table %s' % detection_table)
             db.drop_table("predict_"+customer_type+"_"+customer_name+"_"+str(detection_table.lower()))
         move_directory(INPUT_S3 + customer_type + '/' + customer_name + '/images/', 'deleted_user')
-        logger.info('Archiving input directory for client %s %s' %(customer_name, customer_type))
+        for file in list_repository_files(AZURE_INPUT_PATH + customer_type + '/' + customer_name + '/images/'):
+            copy_azure_file(file, AZURE_CONTAINER_NAME, "deletedUser-" + AZURE_CONTAINER_NAME)
+        logger.info('Archiving input directory for client %s %s' % (customer_name, customer_type))
         move_directory(OUTPUT_S3 + customer_type + '/' + customer_name + '/images/', 'deleted_user')
+        for file in list_repository_files(AZURE_OUTPUT_PATH + customer_type + '/' + customer_name + '/images/'):
+            copy_azure_file(file, AZURE_CONTAINER_NAME, "deletedUser-" + AZURE_CONTAINER_NAME)
         logger.info('Archiving output directory for client %s %s' %(customer_name, customer_type))
         move_directory(VECTORS_S3 + customer_type + '/' + customer_name + '/', 'deleted_user')
+        for file in list_repository_files(AZURE_VECTORS_PATH + customer_type + '/' + customer_name + '/'):
+            copy_azure_file(file, AZURE_CONTAINER_NAME, "deletedUser-" + AZURE_CONTAINER_NAME)
         logger.info('Archiving vectors directory for client %s %s' % (customer_name, customer_type))
         move_directory(TRAININGS_S3 + customer_type + '/' + customer_name + '/', 'deleted_user')
+        for file in list_repository_files(AZURE_TRAINING_PATH + customer_type + '/' + customer_name + '/'):
+            copy_azure_file(file, AZURE_CONTAINER_NAME, "deletedUser-" + AZURE_CONTAINER_NAME)
         logger.info('Archiving training directory for client %s %s' % (customer_name, customer_type))
         for table in tables_to_delete_from:
             if db.delete_from_table(table, customer_name, customer_type):
@@ -1678,4 +1603,117 @@ def get_connected_customer_cms_info(customer_name, customer_type, cms):
             'url_confirmation': result[7]}
     else:
         response = {}
-    return response
\ No newline at end of file
+    return response
+
+
+def delete_project(customer, customer_type, api_project, project_name, project_id):
+    name = project_name + "_deleted" + datetime.date.today().strftime("%Y-%m-%d")
+    db.update_status_name_deleted_project(name, 0, customer, customer_type, project_name, api_project)
+
+    if project_name != "" and api_project == "similars":
+        input_path_project_to_delete = INPUT_PATH + customer_type + '/' + customer + '/images/' + project_name
+        output_path_project_to_delete = OUTPUT_PATH + customer_type + '/' + customer + '/images/' + project_name
+        vectors_path_project_to_delete = VECTORS_PATH + customer_type + '/' + customer + '/' + project_name
+        streams_path_project_similars_to_delete = STREAMS_PATH + customer_type + '/' + customer + '/similars/' + \
+                                                  project_name
+        training_path_project_to_delete = TRAININGS_PATH + customer_type + '/' + customer + '/classification/' + \
+                                          project_name
+
+        vectors_path_s3 = VECTORS_S3 + customer_type + '/' + customer + '/' + project_name
+        output_path_s3 = OUTPUT_S3 + customer_type + '/' + customer + '/images/' + project_name
+        input_path_s3 = INPUT_S3 + customer_type + '/' + customer + '/images/' + project_name
+        streams_path_3 = STREAMS_S3 + customer_type + '/' + customer + '/similars/' + \
+                         project_name
+        training_path_s3_to_delete = TRAININGS_S3 + customer_type + '/' + customer + '/classification/' + \
+                                     project_name
+
+        vectors_path_azure = AZURE_VECTORS_PATH + customer_type + '/' + customer + '/' + project_name
+        output_path_azure = AZURE_OUTPUT_PATH + customer_type + '/' + customer + '/images/' + project_name
+        input_path_azure = AZURE_INPUT_PATH + customer_type + '/' + customer + '/images/' + project_name
+        streams_path_azure = AZURE_STREAMS_PATH + customer_type + '/' + customer + '/similars/' + \
+                             project_name
+        training_path_azure = AZURE_TRAINING_PATH + customer_type + '/' + customer + '/classification/' + \
+                              project_name
+        try:
+            if os.path.isdir(input_path_project_to_delete):
+                if USE_AWS:
+                    move_directory(input_path_s3, 'deleted_project')
+                else:
+                    for file in list_repository_files(input_path_azure):
+                        copy_azure_file(file, AZURE_CONTAINER_NAME, "deleted-" + AZURE_CONTAINER_NAME)
+
+                shutil.rmtree(input_path_project_to_delete)
+                logger.info("input path -------- DELETED")
+            if os.path.isdir(output_path_project_to_delete):
+                if USE_AWS:
+                    move_directory(output_path_s3, 'deleted_project')
+                else:
+                    for file in list_repository_files(output_path_azure):
+                        copy_azure_file(file, AZURE_CONTAINER_NAME, "deleted-" + AZURE_CONTAINER_NAME)
+                shutil.rmtree(output_path_project_to_delete)
+                logger.info("output path -------- DELETED")
+            if os.path.isdir(vectors_path_project_to_delete):
+                if USE_AWS:
+                    move_directory(vectors_path_s3, 'deleted_project')
+                else:
+                    for file in list_repository_files(vectors_path_azure):
+                        copy_azure_file(file, AZURE_CONTAINER_NAME, "deleted-" + AZURE_CONTAINER_NAME)
+                shutil.rmtree(vectors_path_project_to_delete)
+                logger.info("vectors path -------- DELETED")
+            if os.path.isdir(streams_path_project_similars_to_delete):
+                if USE_AWS:
+                    move_directory(streams_path_3, 'deleted_project')
+                else:
+                    for file in list_repository_files(streams_path_azure):
+                        copy_azure_file(file, AZURE_CONTAINER_NAME, "deleted-" + AZURE_CONTAINER_NAME)
+                shutil.rmtree(streams_path_project_similars_to_delete)
+                logger.info("streams path similars -------- DELETED")
+            if os.path.isdir(training_path_project_to_delete):
+                if USE_AWS:
+                    move_directory(training_path_s3_to_delete, 'deleted_project')
+                else:
+                    for file in list_repository_files(training_path_azure):
+                        copy_azure_file(file, AZURE_CONTAINER_NAME, "deleted-" + AZURE_CONTAINER_NAME)
+                shutil.rmtree(training_path_project_to_delete)
+                logger.info("training classification path similars -------- DELETED")
+            return 1
+        except Exception as e:
+            logger.info("Error deleting similars project %s %s " % (project_name, e))
+            return 0
+    elif project_name != "" and api_project == "classification":
+        streams_path_project_classification_to_delete = STREAMS_PATH + customer_type + '/' + customer + \
+                                                        '/classification/' + project_name
+        streams_path_s3_classification_to_delete = STREAMS_S3 + customer_type + '/' + customer + \
+                                                   '/classification/' + project_name
+        training_path_project_to_delete = TRAININGS_PATH + customer_type + '/' + customer + '/classification/' + \
+                                          project_name
+        training_path_s3_to_delete = TRAININGS_PATH + customer_type + '/' + customer + '/classification/' + \
+                                     project_name
+        try:
+            if os.path.isdir(training_path_project_to_delete):
+                move_directory(training_path_s3_to_delete, 'deleted_project')
+                shutil.rmtree(training_path_project_to_delete)
+                logger.info("training path -------- DELETED")
+            if os.path.isdir(streams_path_project_classification_to_delete):
+                move_directory(streams_path_s3_classification_to_delete, 'deleted_project')
+                shutil.rmtree(streams_path_project_classification_to_delete)
+                logger.info("streams path classification -------- DELETED")
+            return 1
+        except Exception as e:
+            logger.info("Error deleting similars project %s %s " % (project_name, e))
+            return 0
+    elif project_name != "" and project_id and api_project == "detection_error":
+        list_directories = ['labels', 'images', 'bottlenecks', 'model', 'model_text', 'output', 'predictCustomerPATH',
+                            'tmp']
+        date_supp = strftime("%d-%m-%Y", gmtime())
+        for directory in list_directories:
+            directory_to_rename = TRAININGS_PATH + str(customer_type) + '/' + str(customer) + '/detection_erreur/' + \
+                                  directory + "/" + project_id
+            directory_s3_rename = TRAININGS_S3 + str(customer_type) + '/' + str(customer) + '/detection_erreur/' + \
+                                  directory + "/" + project_id
+
+            if os.path.isdir(directory_to_rename):
+                os.rename(directory_to_rename, directory_to_rename + '_deleted_' + str(date_supp))
+                logger.info("directory %s -------- RENAMED" % directory)
+                move_directory(directory_s3_rename, 'deleted_project')
+        return 1
\ No newline at end of file
