@@ -74,8 +74,6 @@ def write_to_file(status, last_json, path_new_file, category_will_have_changes=N
                         photo = json_value[index_product]['Photos'][product]
                         photo["Status"] = 1
                     if not block_image_n and not "Status" in json_value[index_product]['Photos'][product]:
-                        print(json_value)
-                        print('Heeeeeeeeeeeeere')
                         photo = json_value[index_product]['Photos'][product]
                         photo["Status"] = 2
                     if category_will_have_changes \
