@@ -180,6 +180,18 @@ def process_customer_stream_from_json(user_apikey, customer_name, customer_type,
     my_queue_json.publish(body)
 
 
+def classfication_after_similars(user_apikey, customer_name, customer_type, project_name):
+    my_queue_json = RabbitMQ(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
+                             mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD,
+                             mqueue_name=MESSAGE_QUEUE_INPUT_NAME,
+                             headers={'user_apikey': user_apikey,
+                                      'operation': 'classfication_after_similars',
+                                      'customer_name': customer_name,
+                                      'customer_type': customer_type,
+                                      'project_name': project_name
+                                      })
+    my_queue_json.publish("")
+
 # Cms process
 def process_customer_stream_cms(user_apikey, customer_name, customer_type, project_name, body):
     my_queue_json = RabbitMQ(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
@@ -688,7 +700,7 @@ def get_all_plans_payement(customer_email, type_user, body):
                                     'operation': 'get_all_plans_payement'},
                            message_body=body)
     value = value.decode('utf-8')
-    rpc_queue.close()
+    
     return value
 
 
@@ -703,7 +715,6 @@ def all_status_projects(customer_name, customer_type, body):
                                     },
                            message_body=body)
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -716,7 +727,6 @@ def all_status_project(user_apikey, customer_name, customer_type):
                                     'user_apikey': user_apikey,
                                     'customer_type': customer_type},
                            message_body='')
-    rpc_queue.close()
     return value.decode("utf-8")
 
 
@@ -728,7 +738,6 @@ def customer_info(data):
                                     'data': data},
                            message_body='')
 
-    rpc_queue.close()
     return value.decode("utf-8")
 
 
@@ -744,7 +753,6 @@ def save_client_reviews(user_apikey, customer_name, customer_type, body, project
                                     'review': review,
                                     'url_image': url_image},
                            message_body=body)
-    rpc_queue.close()
     return value.decode('utf-8')
 
 
@@ -773,7 +781,6 @@ def customer_registration(customer_email, customer_type, customer_name, customer
                            message_body="")
 
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -794,7 +801,6 @@ def update_profile(customer_email, customer_name, first_name, last_name,
                            message_body="")
 
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -813,7 +819,6 @@ def change_password(customer_email, customer_password, new_password, new_passwor
                            message_body="")
 
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -828,7 +833,6 @@ def forget_password(customer_email):
                            message_body="")
 
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -846,7 +850,6 @@ def contact(first_name, customer_email, subject_of_email, message_email):
                            message_body="")
 
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
